@@ -1,17 +1,15 @@
-import gtk, gobject
+import gtk
+import gobject
+import logging
+import deskbar.interfaces.Module
+
+LOGGER = logging.getLogger(__name__)
 
 class ModuleList (gtk.ListStore):
-    """Mostly generic implementation of a dynamic module handler.
-    Use a ModuleListView object to display the contents of a ModuleList. 
-    You can iterate over the list with
+    """
+    Stores a list of available enabled or disabaled modules
     
-        for modctx in modlist:
-            do_something (modctx)
-    
-    From this perspective the ModuleList stores ModuleContexts (it actually doesnt),
-    so to utilize the modules you'll have to acces modctx.module.
-    
-    Note that the gtk.ListView extends the following classes:
+    Note that the gtk.ListStore extends the following classes:
         gobject.GObject, gtk.TreeModel, gtk.TreeDragSource, gtk.TreeDragDest,
         gtk.TreeSortable
     More documentation:
@@ -34,6 +32,10 @@ class ModuleList (gtk.ListStore):
     def __iter__ (self):
         return ModuleListIter (self)
     
+    def _is_module(self, module):
+        if not isinstance(module, deskbar.interfaces.Module):
+            raise TypeError("Expected deskbar.interfaces.Module but got %r" % module)
+        
     def increase_bottom_enabled_path(self):
         self._bottom_enabled_path = (self._bottom_enabled_path[0]+1,)
         
@@ -47,15 +49,17 @@ class ModuleList (gtk.ListStore):
             return None
     
     def get_position_from_context (self, module):
-        """Returns a tuple (iter, index)
+        """
+        Returns a tuple C{(iter, index)}
         
-        iter is a gtk.TreeIter pointing to the row containing the given module module.
+        iter is a gtk.TreeIter pointing to the row containing the given
+        module module.
         index is the index of the module in the list.
         
         If the module is not found return (None, None).
         
         @param module: The module to get the position for
-        @type module: Either a Module instance or the name of a module
+        @type module: Either a L{deskbar.interfaces.Module.Module} instance or the name of a module
         """
         i = 0
         iter = self.get_iter_first ()
@@ -64,9 +68,11 @@ class ModuleList (gtk.ListStore):
                 # Search for module's name
                 if self[iter][self.MODULE_CTX_COL].__class__.__name__ == module:
                     return (iter, i)
-            else:
+            elif isinstance(module, deskbar.interfaces.Module):
                 if self[iter][self.MODULE_CTX_COL] == module:
                     return (iter, i)
+            else:
+                raise TypeError("Expected string or deskbar.interfaces.Module but got %r" % module)
                 
             iter = self.iter_next (iter)
             i = i+1
@@ -93,15 +99,19 @@ class ModuleList (gtk.ListStore):
         self.reorder(new_order)
         
     def add (self, module, iter=None):
-        """If iter is set this method updates the row pointed to by iter with the 
+        """
+        If iter is set this method updates the row pointed to by iter with the 
         values of module. 
         
         If iter is not set it will try to obtain an iter pointing
         to the row containg the module. If there's no such row, it will append it.
         """
+        self._is_module(module)
+        
         for mod in self:
-            if mod == module:
+            if mod.__class__.__name__ == module.__class__.__name__:
                 # We don't want a duplicate module
+                LOGGER.warning("You tried to add a module twice. Not adding %r from %s", mod, mod.get_filename())
                 return
                 
         if iter is None:
@@ -118,12 +128,16 @@ class ModuleList (gtk.ListStore):
         self._mod_to_name[module.__class__.__name__] = module
     
     def remove_module(self, module):
+        self._is_module(module)
+        
         iter, index = self.get_position_from_context(module)
         if iter != None:
-            print 'Removing from modulelist:', module.handler
+            LOGGER.debug('Removing from modulelist: %s', module.INFOS['name'])
             self.remove(iter)
         
     def module_changed(self, module):
+        self._is_module(module)
+        
         iter, index = self.get_position_from_context(module)
         if iter != None:
             self.emit('row-changed', self.get_path(iter), iter)
@@ -139,8 +153,11 @@ class ModuleList (gtk.ListStore):
     def module_toggled_cb (self, sender, module):
         """
         Callback to toggle the enabled state of the module.
-        """
-        self[self.get_position_from_context(module)[0]][self.ENABLED_COL] = module.is_enabled()
+        """ 
+        iter, index = self.get_position_from_context(module)
+        if iter != None:
+            # Only if the module is in the list
+            self[iter][self.ENABLED_COL] = module.is_enabled()
         
     def is_module_enabled(self, iter):
         return self[iter][self.ENABLED_COL]
@@ -161,7 +178,7 @@ class ModuleList (gtk.ListStore):
     def move_module_to_bottom(self, iter):
         self.move_after(iter, self.get_iter(self._bottom_enabled_path))
         
-    def _get_iter_from_module_id(self, modid):
+    def get_iter_from_module_id(self, modid):
         iter = self.get_iter_first ()
         while (iter is not None):
             if self[iter][self.MODULE_CTX_COL].get_id() == modid:
@@ -169,10 +186,9 @@ class ModuleList (gtk.ListStore):
             iter = self.iter_next(iter)
         return None
             
-    def set_module_update_available(self, modid):
-        iter = self._get_iter_from_module_id(modid)
+    def set_module_update_available(self, iter, val):
         if iter != None:
-            self.set_value(iter, self.UPDATEABLE_COL, True)
+            self.set_value(iter, self.UPDATEABLE_COL, val)
 
 gobject.type_register(ModuleList)
 
@@ -192,35 +208,79 @@ class DisabledModuleList (gtk.ListStore):
         self.set_value(iter, self.ICON_COL, module.INFOS['icon'])
         self.set_value(iter, self.MODULE_CTX_COL, module)
         self.set_value(iter, self.ACTIVATABLE_COL, False)
+    
+    def get_position_from_context (self, module):
+        """
+        Returns a tuple C{(iter, index)}
+        
+        iter is a gtk.TreeIter pointing to the row containing the given
+        module module.
+        index is the index of the module in the list.
+        
+        If the module is not found return (None, None).
+        
+        @param module: The module to get the position for
+        @type module: Either a L{deskbar.interfaces.Module.Module} instance or the name of a module
+        
+        Note: This class stores the classes of disabled modules. It doesn't store actual module instances.
+        """
+        i = 0
+        iter = self.get_iter_first ()
+        while (iter is not None):
+            if isinstance(module, str):
+                # Search for module's name
+                if self[iter][self.MODULE_CTX_COL].__name__ == module:
+                    return (iter, i)
+            else:
+                if self[iter][self.MODULE_CTX_COL] == module:
+                    return (iter, i)
+                
+            iter = self.iter_next (iter)
+            i = i+1
+        
+        return (None, 0)
+    
+    def remove_module(self, module):
+        iter, index = self.get_position_from_context(module)
+        if iter != None:
+            LOGGER.debug('Removing from disabledModulelist: %s', str(module))
+            self.remove(iter)
 
 gobject.type_register(DisabledModuleList)
 
 class WebModuleList (gtk.ListStore):
-    MODULE_CTX_COL = 0
+    
+    (MODULE_ID,
+     MODULE_NAME,
+     MODULE_DESCRIPTION) = range (3)
     
     def __init__ (self):
-        # First element is a tuple containing module id, name and description
-        gtk.ListStore.__init__ (self, gobject.TYPE_PYOBJECT, bool)
+        gtk.ListStore.__init__ (self, str, str, str)
+        self.set_sort_column_id (self.MODULE_NAME, gtk.SORT_ASCENDING)
         
-    def __iter__ (self):
-        return ModuleListIter (self)
+    def __contains__ (self, mod_id):
+        for mod in self:
+            if mod_id == mod[0]:
+                return True
+        return False
     
-    def get_position_from_context (self, module, value=None):
-        """Returns a tuple (iter, index)
+    def get_position_from_context (self, module_id, value=None):
+        """
+        @param module_id: A module id
+        @type module_id: str
+        @return: a tuple (iter, index) or (None, 0) if the module is not found
         
-        iter is a gtk.TreeIter pointing to the row containing the given module module.
+        iter is a C{gtk.TreeIter} pointing to the row containing the given module module.
         index is the index of the module in the list.
-        
-        If the module module is not found return (None, None).
         """
         i = 0
         iter = self.get_iter_first ()
         while (iter is not None):
             if value == None:
-                if self[iter][self.MODULE_CTX_COL] == module:
+                if self[iter][self.MODULE_ID] == module_id:
                     return (iter, i)
             else:
-                if getattr(self[iter][self.MODULE_CTX_COL], module) == value:
+                if getattr(self[iter][self.MODULE_ID], module_id) == value:
                     return (iter, i)
             
             iter = self.iter_next (iter)
@@ -228,39 +288,31 @@ class WebModuleList (gtk.ListStore):
         
         return (None, 0)
                 
-    def add (self, module, iter=None):
-        """If iter is set this method updates the row pointed to by iter with the 
+    def add (self, mod_id, mod_name, mod_desc, iter=None):
+        """
+        If iter is set this method updates the row pointed to by iter with the 
         values of module. 
         
         If iter is not set it will try to obtain an iter pointing
         to the row containg the module. If there's no such row, it will append it.
         """
-        (mod_id, mod_name, mod_desc) = module
         for mod in self:
             if mod_id == mod[0]:
                 # We don't want a duplicate module
                 return
-                
+    
         if iter is None:
-            res = self.get_position_from_context(module)
-        if res is None or res[0] is None:
             iter = self.append ()
         
-        self.set_value(iter, self.MODULE_CTX_COL, module)
+        self.set_value(iter, self.MODULE_ID, mod_id)
+        self.set_value(iter, self.MODULE_NAME, mod_name)
+        self.set_value(iter, self.MODULE_DESCRIPTION, mod_desc)
     
     def module_changed(self, module):
         iter, index = self.get_position_from_context(module)
         if iter != None:
             self.emit('row-changed', self.get_path(iter), iter)
-        
-    def update_row_cb (self, sender, module, iter=None):
-        """
-        Callback for updating the row containing module.
-        If iter is set the row to which it points to will be
-        updated with the module.
-        """
-        self.add(module, iter)
-
+   
 gobject.type_register(WebModuleList)
 
 class ModuleListIter : 
