@@ -1,10 +1,13 @@
-import os, pydoc
-from os.path import abspath, expanduser, join, basename
-import traceback
-import gtk, gobject
-import logging
-import deskbar, deskbar.core.Categories
 from deskbar.core.Watcher import DirWatcher
+from os.path import abspath, expanduser, join, basename
+import deskbar
+import deskbar.core.Categories
+import deskbar.interfaces.Module
+import gobject
+import gtk
+import logging
+import os
+import pydoc
 
 LOGGER = logging.getLogger(__name__)
 
@@ -49,7 +52,6 @@ class ModuleLoader (gobject.GObject):
         self.ext = extension
         self.watcher = DirWatcher()
         self.watch_id = self.watcher.connect('changed', self._on_handler_file_changed)
-        self.__old_modules = []
         
         if (dirs):
             self.dirs = [abspath(expanduser(s)) for s in dirs]
@@ -59,9 +61,6 @@ class ModuleLoader (gobject.GObject):
             self.dirs = None
             self.filelist = []
 
-    def get_old_modules(self):
-        return self.__old_modules
-
     def _on_handler_file_changed(self, watcher, f):
         if f in self.filelist or not self.is_module(f):
             return
@@ -83,8 +82,8 @@ class ModuleLoader (gobject.GObject):
                     if basename(i) not in [basename(j) for j in res]:
                         res.append(i)
             except OSError, err:
-                LOGGER.error("Error reading directory %s, skipping." % d)
-                traceback.print_exc()
+                LOGGER.error("Error reading directory %s, skipping.", d)
+                LOGGER.exception(err)
         
         self.filelist = res
             
@@ -97,24 +96,19 @@ class ModuleLoader (gobject.GObject):
         Primarily for internal use."""
         try:
             mod = pydoc.importfile (filename)
-        except Exception:
-            LOGGER.error("Error loading the file: %s." % filename)
-            error = traceback.format_exc()
-            if "No module named deskbar.Handler" in error:
-                self.__old_modules.append(filename)
-            else:
-                print error
+        except Exception, e:
+            LOGGER.error("Error loading the file: %s.", filename)
+            LOGGER.exception(e)
             return
         
         try:
             if (mod.HANDLERS): pass
         except AttributeError:
-            LOGGER.error("The file %s is not a valid module. Skipping. A module must have the variable HANDLERS defined as a list." % filename)
-            #traceback.print_exc()
+            LOGGER.error("The file %s is not a valid module. Skipping. A module must have the variable HANDLERS defined as a list.", filename)
             return
         
         if mod.HANDLERS == None:
-            LOGGER.warning("The file %s doesn't contain a HANDERLS variable" % (filename))
+            LOGGER.warning("The file %s doesn't contain a HANDERLS variable", filename)
             return
         
         valid_modules = []
@@ -126,12 +120,12 @@ class ModuleLoader (gobject.GObject):
             if hasattr(module, "initialize") and hasattr( module, "INFOS"):
                 # Check that the given requirements for the handler are met
                 if not getattr(module, "has_requirements" )():
-                    LOGGER.warning("Class %s in file %s has missing requirements. Skipping." % (handler, filename))
+                    LOGGER.warning("Class %s in file %s has missing requirements. Skipping.", handler, filename)
                     self.emit("module-not-initialized", module)
                 else:
                     valid_modules.append(module)
             else:
-                LOGGER.error("Class %s in file %s does not have an initialize(self) method or does not define a 'INFOS' attribute. Skipping." % (handler, filename))
+                LOGGER.error("Class %s in file %s does not have an initialize(self) method or does not define a 'INFOS' attribute. Skipping.", handler, filename)
             
         return valid_modules
             
@@ -144,8 +138,10 @@ class ModuleLoader (gobject.GObject):
             return
         
         for mod in modules:
-            LOGGER.info("Loading module '%s' from file %s." % ( mod.INFOS["name"], filename))
+            LOGGER.info("Loading module '%s' from file %s.", mod.INFOS["name"], filename)
             mod_instance = mod ()
+            if not isinstance(mod_instance, deskbar.interfaces.Module):
+                raise TypeError("Module %s in %s is not a sub-class of deskbar.interfaces.Module" % (mod, filename))
             mod_instance.set_filename( filename )
             mod_instance.set_id( os.path.basename(filename) )
                     
@@ -157,9 +153,9 @@ class ModuleLoader (gobject.GObject):
         passing a corresponding module module.
         """
         if self.dirs is None:
-            LOGGER.error("The ModuleLoader at %s has no filelist! It was probably initialized with dirs=None." % str(id(self)))
+            LOGGER.error("The ModuleLoader at %s has no filelist! It was probably initialized with dirs=None.", str(id(self)))
             return
-            
+        
         for f in self.filelist:
             self.load (f)
         
@@ -171,10 +167,13 @@ class ModuleLoader (gobject.GObject):
         when done, passing the (now enabled) contextas argument.
         If module is already initialized, do nothing.
         """
+        if not isinstance(module, deskbar.interfaces.Module):
+            raise TypeError("Module is not a sub-class of deskbar.interfaces.Module")
+        
         if module.is_enabled():
             return
             
-        LOGGER.info("Initializing %s" % module.INFOS["name"])
+        LOGGER.info("Initializing %s", module.INFOS["name"])
         
         try:
             module.initialize ()
@@ -184,8 +183,8 @@ class ModuleLoader (gobject.GObject):
                 for catname, catinfo in module.INFOS["categories"].items():
                     deskbar.core.Categories.CATEGORIES[catname] = catinfo
         except Exception, msg:
-            LOGGER.error( "Error while initializing %s: %s" % (module.INFOS["name"],msg))
-            traceback.print_exc()
+            LOGGER.error( "Error while initializing %s: %s", module.INFOS["name"], msg)
+            LOGGER.exception(msg)
             module.set_enabled(False)
             self.emit("module-not-initialized", module)
             return
@@ -199,8 +198,10 @@ class ModuleLoader (gobject.GObject):
         instance is also set to None. Emits a 'module-stopped' signal when done passing
         the stopped module as argument.
         """
+        if not isinstance(module, deskbar.interfaces.Module):
+            raise TypeError("Module is not a sub-class of deskbar.interfaces.Module")
         
-        LOGGER.info("Stopping %s" % module.INFOS["name"])
+        LOGGER.info("Stopping %s", module.INFOS["name"])
         module.stop ()
                 
         module.set_enabled(False)
