@@ -282,9 +282,6 @@ class DeskbarPreferences:
 
     def on_use_selection_toggled(self, toggle):
         self._model.set_use_selection(toggle.get_active())
-
-    def on_use_newstyleui_toggled(self, toggle):
-        self._model.set_use_newstyleui(toggle.get_active())
         
     def on_more_button_clicked(self, button):
         if self.more_button_callback != None:
@@ -570,7 +567,7 @@ class DeskbarPreferences:
             self._show_module_installed_dialog()
         except Exception, e:
             dialog = ErrorDialog(self.dialog,
-                                 _("Extension could not be installed due a problem with the provided file"),
+                                 _("Extension could not be installed due to a problem with the provided file"),
                                  traceback.format_exc() )
             dialog.run()
         
@@ -578,31 +575,35 @@ class DeskbarPreferences:
     
     def on_button_top_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
-        self.module_list.move_module_to_top(iter)
-        self.moduleview.scroll_to_iter(iter)
-        self.set_buttons(self.moduleview.get_selection())
-        self.moduleview.grab_focus()
+        if iter != None:
+            self.module_list.move_module_to_top(iter)
+            self.moduleview.scroll_to_iter(iter)
+            self.set_buttons(self.moduleview.get_selection())
+            self.moduleview.grab_focus()
     
     def on_button_up_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
-        self.module_list.move_module_up(iter)
-        self.moduleview.scroll_to_iter(iter)
-        self.set_buttons(self.moduleview.get_selection())
-        self.moduleview.grab_focus()
+        if iter != None:
+            self.module_list.move_module_up(iter)
+            self.moduleview.scroll_to_iter(iter)
+            self.set_buttons(self.moduleview.get_selection())
+            self.moduleview.grab_focus()
     
     def on_button_down_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
-        self.module_list.move_module_down(iter)
-        self.moduleview.scroll_to_iter(iter)
-        self.set_buttons(self.moduleview.get_selection())
-        self.moduleview.grab_focus()
+        if iter != None:
+            self.module_list.move_module_down(iter)
+            self.moduleview.scroll_to_iter(iter)
+            self.set_buttons(self.moduleview.get_selection())
+            self.moduleview.grab_focus()
     
     def on_button_bottom_clicked(self, button):
         model, iter = self.moduleview.get_selection().get_selected()
-        self.module_list.move_module_to_bottom(iter)
-        self.moduleview.scroll_to_iter(iter)
-        self.set_buttons(self.moduleview.get_selection())
-        self.moduleview.grab_focus()
+        if iter != None:
+            self.module_list.move_module_to_bottom(iter)
+            self.moduleview.scroll_to_iter(iter)
+            self.set_buttons(self.moduleview.get_selection())
+            self.moduleview.grab_focus()
         
     def on_ui_changed(self, check):
         if self.sticktopanel_checkbox.get_active():
